@@ -1,3 +1,4 @@
+import logging
 import os
 import queue
 import threading
@@ -5,6 +6,8 @@ import time
 
 from dusted.config import config
 
+logger = logging.getLogger(__name__)
+
 watcher = None
 stdout = queue.Queue()
 
@@ -20,6 +23,7 @@ class LogfileWatcher:
             try:
                 new_size = os.path.getsize(self.path)
                 if self.file is None or new_size < self.size:
+                    logger.info("Opening new log file")
                     if self.file is not None:
                         self.file.close()
                     self.file = open(self.path, "r")
@@ -38,9 +42,11 @@ class LogfileWatcher:
 def create_proc(uri):
     global watcher
     if watcher is None:
+        logger.info("Starting logfile watcher thread")
         path = os.path.join(config.dustforce_path, "output.log")
         watcher = LogfileWatcher(path)
         logfile_thread = threading.Thread(target=watcher.start, daemon=True)
         logfile_thread.start()
 
+    logger.info(f"Opening uri: {uri}")
     os.startfile(uri)
