@@ -1,3 +1,4 @@
+import logging
 import os
 import queue
 import re
@@ -15,6 +16,8 @@ from .level import Level
 from .level_view import LevelView
 from .replay import Replay
 
+logger = logging.getLogger(__name__)
+
 LEVEL_PATTERN = r"START (.*)"
 COORD_PATTERN = r"(\d*) (-?\d*) (-?\d*)"
 CHARACTERS = ["dustman", "dustgirl", "dustkid", "dustworth"]
@@ -26,6 +29,7 @@ class LoadReplayDialog(SimpleDialog):
         self.app = app
 
     def ok(self, replay_id):
+        logger.info(f"Loading replay from id: {replay_id}")
         replay = utils.load_replay_from_dustkid(replay_id)
         self.app.load_replay(replay)
         return True
@@ -57,6 +61,7 @@ class NewReplayDialog(Dialog):
     def ok(self):
         level_id = self.level_entry.get()
         character = CHARACTERS.index(self.character_var.get())
+        logger.info(f"Creating new replay with level id {level_id} and character {character}")
         self.app.file = None
         self.level.set(level_id)
         self.app.character = character
@@ -115,10 +120,13 @@ class App(tk.Tk):
 
         self.canvas = canvas
         self.file = None
+
+        logger.info("Starting stdout handling loop")
         self.after_idle(self.handle_stdout)
 
         # Check if the Dustforce directory is valid
         if not os.path.isdir(config.dustforce_path):
+            logger.warning("The provided dustforce path does not exist")
             tk.messagebox.showwarning(message="Could not find the Dustforce directory. Please update it in Settings.")
 
     def handle_stdout(self):
@@ -132,14 +140,17 @@ class App(tk.Tk):
             self.after(16, self.handle_stdout)
 
     def watch(self):
+        logger.info("Watching replay")
         if self.save_file():
             dustforce.watch_replay(self.file)
 
     def load_state_and_watch(self):
+        logger.info("Loading state and watching replay")
         if self.save_file():
             dustforce.watch_replay_load_state(self.file)
 
     def save_file(self, save_as=False):
+        logger.info("Saving file")
         if not self.file or save_as:
             self.file = tk.filedialog.asksaveasfilename(
                 defaultextension=".dfreplay",
@@ -163,10 +174,12 @@ class App(tk.Tk):
             title="Load replay"
         )
         if filepath:
+            logger.info(f"Opening replay from file: {filepath}")
             replay = utils.load_replay_from_file(filepath)
             self.load_replay(replay, filepath)
 
     def load_replay(self, replay, filepath=None):
+        logger.info("Loading replay")
         self.file = filepath
         self.level.set(replay.level)
         self.character = replay.characters[0]
@@ -176,5 +189,6 @@ class App(tk.Tk):
         current_path = config.dustforce_path
         new_path = tk.filedialog.askdirectory(initialdir=current_path)
         if new_path:
+            logger.info(f"Dustforce directory set to: {new_path}")
             config.dustforce_path = new_path
         config.write()
